@@ -42,7 +42,7 @@ class Commit:
             raise NoCommitBackupError()
 
         # Read commit message from backup
-        with open(self.temp_file, "r", encoding=self.encoding) as f:
+        with open(self.temp_file, encoding=self.encoding) as f:
             return f.read().strip()
 
     def prompt_commit_questions(self) -> str:
@@ -98,9 +98,14 @@ class Commit:
         )
 
         if signoff:
-            c = git.commit(m, "-s")
+            out.warn(
+                "signoff mechanic is deprecated, please use `cz commit -- -s` instead."
+            )
+            extra_args = self.arguments.get("extra_cli_args", "--") + " -s"
         else:
-            c = git.commit(m)
+            extra_args = self.arguments.get("extra_cli_args", "")
+
+        c = git.commit(m, args=extra_args)
 
         if c.return_code != 0:
             out.error(c.err)
