@@ -1,3 +1,5 @@
+import re
+
 from commitizen.cz import exceptions
 
 
@@ -9,3 +11,7 @@ def required_validator(answer, msg=None):
 
 def multiple_line_breaker(answer, sep="|"):
     return "\n".join(line.strip() for line in answer.split(sep) if line)
+
+
+def strip_local_version(version: str) -> str:
+    return re.sub(r"\+.+", "", version)
